/**
 * Copyright (c) 2008-2012 EBM WebSourcing, 2012-2017 Linagora
 *
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 *
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see http://www.gnu.org/licenses/
 * for the GNU Lesser General Public License version 2.1.
 */ 
package org.ow2.petals.usecase.jsr181;

import java.text.SimpleDateFormat;
import java.util.Date;
import java.util.Set;

import javax.annotation.Resource;
import javax.jws.WebMethod;
import javax.jws.WebService;
import javax.xml.ws.WebServiceContext;

/**
 * @author Christophe Hamerling - EBM WebSourcing
 * <p>
 * NOTE : The @WebService parameters are not used by the component, the service name is
 * defined in the service unit. Need to modify the CDK to be able to
 * create the endpoint from these values.
 * </p>
 */
@WebService(serviceName = "MyService", name = "MyService", targetNamespace ="http://petals.ow2.org")
public class TestService {

    @Resource
    private WebServiceContext context;

    public TestService() {
    }

    /**
     * Say hello to the world !
     */
    @WebMethod
    public String sayHello(String str) {
        System.out.println("Hey! This is the sayHello operation.");
        return "You say me " + str;
    }
    
    /**
     * Say good bye to 2 persons
     */
    @WebMethod
    public String sayGoodBye(String name1, String name2) {
        System.out.println("Bye! This is the sayGoodBye operation.");
        return "Good bye " + name1 + " and " + name2;
    }

    /**
     * Get a person from its id
     * 
     * @param id
     * @return
     */
    @WebMethod
    public Person getPerson(int id) {
        System.out.println("Get person " + id);
        return new Person(id, "Christophe", "Hamerling", 29, "France");
    }

    /**
     * 
     * @return
     */
    @WebMethod
    public String getTime() {
        System.out.println("Get time");
        return new SimpleDateFormat().format(new Date(System.currentTimeMillis()));
    }

    /**
     * NOP
     */
    @WebMethod
    public void voidvoid() {
        System.out.println("The Void operation");
    }

    /**
     * The final operation will be 'specializedOperation'
     */
    @WebMethod(operationName = "specializedOperation")
    public void operation() {
        System.out.println("The specialized operation");
    }

    /**
     * 
     * @throws Exception
     */
    @WebMethod
    public String iAmThrowingAnException() throws Exception {
        System.out.println("throw exception");
        throw new Exception("This is a server side Exception");
    }

}
